@@ -4,9 +4,12 @@ Use of this source code is governed by an MIT-style license that can be found in
 """
 
 from .boolean_validators import MappedBooleanValidator
+from .comma_separated_list_validator import CommaSeparatedListValidator
 from .date_validator import ParsedDateValidator
 from .datetime_validator import Rfc1123DateTimeValidator, SpacedDateTimeValidator, TimestampDateTimeValidator
 from .decimal_validators import GermanDecimalValidator
+from .float_to_integer_validator import FloatToIntegerValidators
+from .geojson_geometry_validator import GeoJSONGeometryValidator
 from .integer_validators import GermanDurationIntegerValidator
 from .iso_duration_validator import IsoDurationValidator
 from .list_validator import DumpedListValidator, PointCoordinateTupleValidator
